pub enum SeekFrom {
Start(u64),
End(i64),
Current(i64),
}🔬This is a nightly-only experimental API. (
alloc_io)Expand description
Enumeration of possible methods to seek within an I/O object.
It is used by the Seek trait.
Variants
Start(u64)
🔬This is a nightly-only experimental API. (
alloc_io)Sets the offset to the provided number of bytes.
End(i64)
🔬This is a nightly-only experimental API. (
alloc_io)Sets the offset to the size of this object plus the specified number of bytes.
It is possible to seek beyond the end of an object, but it’s an error to seek before byte 0.
Current(i64)
🔬This is a nightly-only experimental API. (
alloc_io)Sets the offset to the current position plus the specified number of bytes.
It is possible to seek beyond the end of an object, but it’s an error to seek before byte 0.