pub trait ComponentRefShared<'a>: ComponentRef<'a> { }Expand description
&T where T is some component type
Used when consistency demands that references to component types, rather than component types themselves, be supplied as a type parameter to a function that cannot operate on unique references.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".