pub struct UnsafeMut<'a, T>(/* private fields */);Implementations
Sourceimpl<'a, T> UnsafeMut<'a, T>
impl<'a, T> UnsafeMut<'a, T>
Sourcepub unsafe fn upgrade(scope: &'a UnsafeScope, v: &mut T) -> Self
pub unsafe fn upgrade(scope: &'a UnsafeScope, v: &mut T) -> Self
Safety
Extending lifetimes is unsafe and when done wrongly can cause undefined behaviour. Make sure lifetime can be extended to the scope where data behind reference won’t be moved.