pub unsafe trait DynamicBundle {
// Provided method
fn has<T>(&self) -> bool
where T: Component { ... }
}Expand description
A dynamically typed collection of components
Bundles composed of exactly the same types are semantically equivalent, regardless of order. The
interface of this trait, except has is a private implementation detail.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".