pub trait Query {
type Item<'a>;
}Expand description
A collection of component types to fetch from a World
The interface of this trait is a private implementation detail.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".